@@ -1,4 +1,4 @@
-use crate::filter::Filter;
+use crate::filter::{Filter, FilterError};
 use crate::state::StateManager;
 use crate::ExtractorValue;
 
@@ -15,17 +15,15 @@ impl FlipFlopFilter {
 }
 
 impl Filter for FlipFlopFilter {
-    fn filter(&mut self, value: &ExtractorValue, _state_manager: &mut StateManager) -> bool {
-        match value {
-            ExtractorValue::None => (),
-            _ => {
-                panic!("Wrong value provided for flip flop filter.");
-            }
-        };
-
+    fn filter(
+        &mut self,
+        _value: &ExtractorValue,
+        _state_manager: &mut StateManager,
+    ) -> Result<bool, FilterError> {
         let current_state = !self.state;
         self.state = current_state;
-        current_state
+
+        Ok(current_state)
     }
 }
 
@@ -33,60 +31,49 @@ impl Filter for FlipFlopFilter {
 mod test {
     use super::*;
 
-    const VALUE_1: u8 = 0xff;
-
     #[test]
-    fn flip_flop_filter_initial_false_test() {
+    fn initial_false_test() {
         let mut state_manager = StateManager::new();
         let mut filter = FlipFlopFilter::new(false);
 
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
     }
 
     #[test]
-    fn flip_flop_filter_initial_true_test() {
+    fn initial_true_test() {
         let mut state_manager = StateManager::new();
         let mut filter = FlipFlopFilter::new(true);
 
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
     }
-
-    #[test]
-    #[should_panic(expected = "Wrong value provided for flip flop filter.")]
-    fn flip_flop_filter_value_has_bad_type_test() {
-        let mut state_manager = StateManager::new();
-        let mut filter = FlipFlopFilter::new(true);
-
-        filter.filter(&ExtractorValue::U8(VALUE_1), &mut state_manager);
-    }
 }
