@@ -26,8 +26,18 @@ pub const COUNT_STATE_FILTER_CODE: u16 = 0x0007;
 pub const BOOL_IS_EQUAL_STATE_FILTER_CODE: u16 = 0x0008;
 pub const BOOL_SET_STATE_FILTER_CODE: u16 = 0x0009;
 
+#[derive(Debug, PartialEq)]
+pub enum FilterError {
+    WrongValueType,
+    WrongStateType,
+}
+
 pub trait Filter: Downcast + Debug {
-    fn filter(&mut self, value: &ExtractorValue, state_manager: &mut StateManager) -> bool;
+    fn filter(
+        &mut self,
+        value: &ExtractorValue,
+        state_manager: &mut StateManager,
+    ) -> Result<bool, FilterError>;
 }
 
 impl_downcast!(Filter);
